# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/CalibrationCurve',
                'doc_host': 'https://Rhys-McAlister.github.io',
                'git_url': 'https://github.com/Rhys-McAlister/CalibrationCurve',
                'lib_path': 'CalibrationCurve'},
  'syms': { 'CalibrationCurve.core': { 'CalibrationCurve.core.CalibrationModel': ('core.html#calibrationmodel', 'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.__init__': ( 'core.html#calibrationmodel.__init__',
                                                                                            'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.calculate_sse': ( 'core.html#calibrationmodel.calculate_sse',
                                                                                                 'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.calculate_sxhat': ( 'core.html#calibrationmodel.calculate_sxhat',
                                                                                                   'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.calculate_syx': ( 'core.html#calibrationmodel.calculate_syx',
                                                                                                 'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.calculate_uncertainty': ( 'core.html#calibrationmodel.calculate_uncertainty',
                                                                                                         'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.fit_model': ( 'core.html#calibrationmodel.fit_model',
                                                                                             'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.fit_ols': ( 'core.html#calibrationmodel.fit_ols',
                                                                                           'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.get_params': ( 'core.html#calibrationmodel.get_params',
                                                                                              'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.get_r2': ( 'core.html#calibrationmodel.get_r2',
                                                                                          'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.get_t_value': ( 'core.html#calibrationmodel.get_t_value',
                                                                                               'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.inverse_prediction': ( 'core.html#calibrationmodel.inverse_prediction',
                                                                                                      'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.load_data': ( 'core.html#calibrationmodel.load_data',
                                                                                             'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.plot_fit': ( 'core.html#calibrationmodel.plot_fit',
                                                                                            'CalibrationCurve/core.py'),
                                       'CalibrationCurve.core.CalibrationModel.tabulate_results': ( 'core.html#calibrationmodel.tabulate_results',
                                                                                                    'CalibrationCurve/core.py')}}}
